package org.gnu.glade;

import java.lang.reflect.Method;

import org.gnu.gtk.event.FocusEvent;
import org.gnu.gtk.event.FocusListener;

/**
 * FocusListener delegate class.
 * 
 * @author Tom Ball
 */
class FocusDelegate extends ListenerDelegate implements FocusListener {

    public FocusDelegate(String signal, Object owner, Method handler,
            Object target) throws NoSuchMethodException {
        super(signal, owner, handler, target);
    }

    public boolean focusEvent(FocusEvent event) {
        return fireEvent(event);
    }
}
